"""
__main__.py
====================================
Core file of the nwtoolkit
"""

import nwtoolkit
import nwtoolkit.environment
import click
import sys
from ipaddress import IPv4Address
import logging

class MultiCommand(click.MultiCommand):
    def list_commands(self, ctx):
        command_list = []
        for plugin in nwtoolkit._plugin_list:
            command_list.append(plugin.split('.')[-1])
        return command_list

    def get_command(self, ctx, name):
        plugin_path = nwtoolkit._plugin_list[name]
        __import__(plugin_path)
        plugin = eval(plugin_path)
        try:
            entry = vars(plugin)[name]
            if type(entry) is click.Command:
                return entry
        except KeyError:
            pass

@click.group(cls=MultiCommand)
@click.option('-v', '--verbose', count=True, help='Increase print verbosity')
@click.option('-q', '--quiet', count=True, help='Decrease print verbosity')
@click.option('--head', help='IP address of the NetWitness head unit', type=IPv4Address)
@click.option('--plugins', help='Custom plugin directory', type=click.Path(exists=True, file_okay=False), multiple=True)
@click.pass_context
def commands(ctx, verbose, quiet, head, plugins):
    if '--help' in sys.argv:
        ctx.obj = None
    else:
        ctx.obj = nwtoolkit.environment.Environment(head=head)
    verbosity = verbose - quiet
    if verbosity > 0:
        logging.basicConfig(format='%(asctime)s %(levelname)s %(message)s', level=logging.DEBUG)
    elif verbosity == 0:
        logging.basicConfig(format='%(message)s', level=logging.INFO)
    elif verbosity == -1:
        logging.basicConfig(format='%(message)s', level=logging.WARNING)
    elif verbosity < -1:
        logging.basicConfig(format='%(message)s', level=logging.ERROR)

def main():
    commands()

if __name__ == '__main__':
    main()
