import json

Components = {
    'Head Unit': {
        'services': ['nginx', 'rabbitmq-ui', 'rabbitmq-ampqs', 'ssh', 'dns', 'salt', 'rsa_update_repo', 'mongodb', 'content_server', 'admin_server', 'integration_server', 'source_server', 'license_server']
    },
    'ESA': {
        'services': ['rabbitmq-ui', 'ssh', 'mongodb', 'context_hub', 'application_port_30', 'application_port_35', 'application_port_36', 'rabbitmq_amqps', 'http', 'https']
    },
    'Archiver': {
        'services': ['rabbitmq-ui', 'https', 'ssh', 'archiver_application_port_50008', 'archiver_application_port_ssl', 'archiver_application_port_rest',
                     'appliance_port_ssl', 'appliance_port_rest', 'rabbitmq-amqps', 'workbench_514', 'workbench_6514', 'workbench_non-ssl', 'workbench_ssl', 'workbench_rest', 'workbench_udp']
    },
    'Broker': {
        'services': ['rabbitmq-ui', 'ssh', 'rsa_update_repo', 'broker_application_port_non-ssl', 'broker_application_port_ssl', 'broker_application_port_rest', 'appliance_port_ssl',
                     'appliance_port_rest', 'rabbitmq-ampqs']
    },
    'Concentrator': {
        'services': ['rabbitmq-ui', 'ssh', 'conc_application_ports_non-ssl', 'conc_application_port_ssl', 'conc_application_port_rest', 'malware_non-ssl', 'malware_ssl', 'appliance_port_ssl',
                     'appliance_port_rest', 'rabbitmq_amqps']
    },
    'Endpoint Log Hybrid': {
        'services': ['nginx_tcp', 'nginx_udp', 'ui-web-7050', 'ui-web-7054', 'collector_app_port_non-ssl', 'collector_app_port_ssl', 'collector_app_port_rest', 'decoder_app_port_non-ssl'
                     'decoder_app_port_ssl', 'decoder_app_port_rest', 'rabbitmq-ui']
    },
    'Relay Server': {
        'services': ['forward_data', 'pull_data']
    },
    'Log Collector': {
        'services': ['rabbitmq-ui', 'ssh', 'syslog_tcp', 'snmp_udp', 'syslog_udp', 'netflow_2055_udp', 'netflow_4739_udp', 'netflow_6343_udp', 'netflow_9995_udp', 'ftp/s_21', 'ftp/s_64000',
                     'ftp/s_64001', 'ftp/s_64002', 'ftp/s_64003', 'ftp/s_64004', 'ftp/s_64005', 'ftp/s_64006', 'ftp/s_64007', 'ftp/s_64008', 'ftp/s_64009', 'collector_app_port_non-ssl',
                     'collector_app_port_ssl', 'collector_app_port_rest', 'appliance_port_ssl', 'appliance_port_rest', 'rabbitmq-amqps', 'virtual_collector_pull', 'collector_push']
    },
    'Log Decoder': {
        'services': ['rabbitmq-ui', 'ssh', 'syslog_tcp', 'snmp_udp', 'syslog_udp', 'netflow_2055_udp', 'netflow_4739_udp', 'netflow_6343_udp', 'netflow_9995_udp', 'ftp/s_21', 'ftp/s_64000',
                     'ftp/s_64001', 'ftp/s_64002', 'ftp/s_64003', 'ftp/s_64004', 'ftp/s_64005', 'ftp/s_64006', 'ftp/s_64007', 'ftp/s_64008', 'ftp/s_64009', 'collector_app_port_non-ssl',
                     'collector_app_port_ssl', 'collector_app_port_rest', 'decoder_app_port_non-ssl', 'decoder_app_port_ssl', 'decoder_app_port_rest', 'decoder_app_port_endpoint', 'appliance_port_ssl',
                     'appliance_port_rest', 'rabbitmq-amqps', 'virtual_collector_pull', 'collector_push']
    },
    'Log Hybrid': {
        'services': ['rabbitmq-ui', 'ssh', 'syslog_tcp', 'snmp_udp', 'syslog_udp', 'netflow_2055_udp', 'netflow_4739_udp', 'netflow_6343_udp', 'netflow_9995_udp', 'ftp/s_21', 'ftp/s_64000',
                     'ftp/s_64001', 'ftp/s_64002', 'ftp/s_64003', 'ftp/s_64004', 'ftp/s_64005', 'ftp/s_64006', 'ftp/s_64007', 'ftp/s_64008', 'ftp/s_64009', 'collector_app_port_non-ssl',
                     'collector_app_port_ssl', 'collector_app_port_rest', 'decoder_app_port_non-ssl', 'decoder_app_port_ssl', 'decoder_app_port_rest', 'decoder_app_port_endpoint',
                     'conc_application_ports_non-ssl', 'conc_application_ports_ssl', 'conc_application_ports_rest', 'appliance_port_ssl', 'appliance_port_rest', 'rabbitmq-amqps']
    },
    'Malware': {
        'services': ['rabbitmq-ui', 'ssh', 'mal_app_ports', 'appliance_port_ssl', 'appliance_port_rest', 'rabbitmq-ampq', 'postgresql', 'broker_application_port_ssl', 'broker_application_port_rest']
    },
    'Network Decoder': {
        'services': ['rabbitmq-ui', 'ssh', 'net_decoder_app_ports_non-ssl', 'net_decoder_app_ports_ssl', 'net_decoder_app_ports_rest', 'appliance_port_ssl', 'appliance_port_rest', 'rabbitmq-ampq']
    },
    'Network Hybrid': {
        'services': ['rabbitmq-ui', 'ssh', 'net_decoder_app_ports_non-ssl', 'net_decoder_app_ports_ssl', 'net_decoder_app_ports_rest', 'appliance_port_ssl', 'appliance_port_rest', 'rabbitmq-ampq',
                     'conc_application_ports_non-ssl', 'conc_application_port_ssl', 'conc_application_port_rest']
    },
    'UEBA': {
        'services': ['ssh', 'monitoring', 'rabbitmq-ampq', 'rabbitmq-ui']
    },
    'Analyst UI': {
        'services': ['ssh', 'rabbitmq-ampq']
    },
    'HW Beta': {
        'services': ['ssh', 'rabbitmq-ampq', 'kibana', 'elasticsearch', 'rabbitmq-ui', 'metrics-server', 'node-infra']
    },
    'Log Retention Hybrid': {
        'services': ['rabbitmq-ui', 'ssh', 'syslog_tcp', 'snmp_udp', 'syslog_udp', 'netflow_2055_udp', 'netflow_4739_udp', 'netflow_6343_udp', 'netflow_9995_udp', 'ftp/s_21', 'ftp/s_64000',
                     'ftp/s_64001', 'ftp/s_64002', 'ftp/s_64003', 'ftp/s_64004', 'ftp/s_64005', 'ftp/s_64006', 'ftp/s_64007', 'ftp/s_64008', 'ftp/s_64009', 'collector_app_port_non-ssl',
                     'collector_app_port_ssl', 'collector_app_port_rest', 'decoder_app_port_non-ssl', 'decoder_app_port_ssl', 'decoder_app_port_rest', 'decoder_app_port_endpoint',
                     'appliance_port_ssl', 'appliance_port_rest', 'rabbitmq-amqps']
    }

}

Services = {
    'nginx': [80],
    'dns': [53],
    'syslog': [514],
    'rabbitmq-ui': [15671],
    'rabbitmq-ampqs': [5671],
    'rsa_update_repo': [443],
    'ssh': [22],
    'postgresql': [5432],
    'mongodb': [27017],
    'context_hub': [7005],
    'application_port_30': [50030],
    'application_port_35': [50035],
    'application_port_36': [50036],
    'live': [443],
    'http': [80],
    'https': [443],
    'salt': [4505, 4506],
    'network_application_port_non-ssl': [56004],
    'network_application_port_ssl': [50004],
    'archiver_application_port_50008': [50008],
    'archiver_application_port_ssl': [56008],
    'archiver_application_port_rest': [50108],
    'appliance_port_ssl': [56006],
    'appliance_port_rest': [50106],
    'broker_application_port_non-ssl': [50003],
    'broker_application_port_ssl': [56003],
    'broker_application_port_rest': [50103],
    'conc_application_ports_non-ssl': [50005],
    'conc_application_port_ssl': [56005],
    'conc_application_port_rest': [50105],
    'malware_non-ssl': [50005],
    'malware_ssl': [56006],
    'nginx_tcp': [443],
    'nginx_udp': [444],
    'ui-web-7050': [7050],
    'ui-web-7054': [7054],
    'collector_app_port_non-ssl': [50001],
    'collector_app_port_ssl': [56001],
    'collector_app_port_rest': [50101],
    'decoder_app_port_non-ssl': [50002],
    'decoder_app_port_ssl': [56002],
    'decoder_app_port_rest': [50102],
    'forward_data': [443],
    'pull_data': [443],
    'net_decoder_app_ports_ssl': [56004],
    'net_decoder_app_ports_rest': [50104],
    'net_decoder_app_ports_non-ssl': [50004],
    'monitoring': [443],
    'kibana': [5601],
    'elasticsearch': [9200],
    'metrics-server': [7018],
    'node-infra': [7020],
    'content_server': [7006],
    'admin_server': [7009],
    'integration_server': [7012],
    'source_server': [7015],
    'license_server': [7016],
    'log_hybrid1': [64000],
    'log_hybrid2': [64001],
    'log_hybrid3': [64002],
    'log_hybrid4': [64003],
    'log_hybrid5': [64004],
    'log_hybrid6': [64005],
    'log_hybrid7': [64006],
    'log_hybrid8': [64007],
    'log_hybrid9': [64008],
    'log_hybrid10': [64009],
    'log_retention1': [2055],
    'log_retention2': [4739],
    'log_retention3': [6343],
    'log_retention4': [9995],
    'log_retention5': [21],
    'log_retention6': [56202],
    'endpoint_standalone1': [25672],
    'endpoint_standalone2': [7056],
    'endpoint_standalone3': [4369]
}

Appliance_Sockets = {
    'AdminServer': {
        'services': [443, 80, 15671, 22, 53, 4505, 4506, 5671, 27017]
    },
    'ESAPrimary': {
        'services': [15671, 22, 27017, 7005, 50030, 50035, 50036, 5671, 80, 443, 7007]
    },
    'ESASecondary': {
        'services': [15671, 22, 27017, 7005, 50030, 50035, 50036, 5671, 80, 443, 7007]
    },
    'Archiver': {
        'services': [15671, 22, 50008, 56008, 50108, 56006, 50106, 5671, 50007, 56007, 50107]
    },
    'Broker': {
        'services': [15671, 22, 50003, 56003, 50103, 56006, 50106, 5671]
    },
    'Concentrator': {
        'services': [15671, 22, 50005, 56005, 50105, 56006, 50106, 5671]
    },
    'Endpoint': {
        'services': [443, 15671, 27017, 25672, 7056, 22]
    },
    'EndpointLogHybrid': {
        'services': [443, 514, 6514, 7050, 7054, 50001, 56001, 50101, 15671]
    },
    'RelayServer': {
        'services': [443]
    },
    'LogCollector': {
        'services': [15671, 22, 514, 4739, 6343, 2055, 9995, 21, 64000, 64001, 64002, 64003, 64004, 64005, 64006, 64007, 64008, 64009, 50001, 56001, 50101, 6006, 50106, 5671]
    },
    'LogDecoder': {
        'services': [15671, 22, 514, 4739, 6343, 2055, 9995, 21, 64000, 64001, 64002, 64003, 64004, 64005, 64006, 64007, 64008, 64009, 50001, 56001, 50101, 6006, 50106, 5671, 6514]
    },
    'LogHybrid': {
        'services': [15671, 22, 514, 2055, 4739, 6343, 9995, 21, 64000, 64001, 64002, 64003, 64004, 64005, 64006, 64007, 64008, 64009, 50001, 56001, 50101, 50002, 56002, 56202, 50102,
                     50005, 56005, 50105, 56002, 56202, 50102, 5671]
    },
    'Malware': {
        'services': [15671, 22, 6007, 56006, 50106, 5671, 5432, 56003, 50103]
    },
    'Decoder': {
        'services': [15671, 22, 56004, 50104, 50004, 56006, 50106, 5671]
    },
    'PacketHybrid': {
        'services': [15671, 22, 56004, 50104, 50004, 50005, 56005, 50105, 56006, 50106, 5671]
    },
    'UEBA': {
        'services': [443, 22, 15671, 5671]
    },
    'AnalystUI': {
        'services': [22, 15671, 5671]
    },
    'Search': {
        'services': [22, 5601, 9200, 5671, 15671, 7018, 7020]
    },
    'IncLogDecoder': {
        'services': [15671, 22, 514, 2055, 4739, 6343, 9995, 21, 64000, 64001, 64002, 64003, 64004, 64005, 64006, 64007, 64008, 64009, 50001, 56001, 50101, 50002, 56002, 56202, 50102, 56006, 50106, 5671]
    }

}

Direction = {
    'adminserver': ['AnalystUI', 'Broker', 'Concentrator', 'Endpoint', 'EndpointLogHybrid', 'EndpointBroker', 'LogHybrid', 'PacketHybrid'],
    'AnalystUI': ['AdminServer', 'Concentrator'],
    'Archiver': ['AdminServer', 'LogDecoder'],
    'Broker': ['AdminServer', 'Concentrator', 'LogHybrid', 'PacketHybrid'],
    'Concentrator': ['AdminServer', 'LogDecoder', 'Decoder', 'AdminServer', 'Broker', 'AnalystUI'],
    'Decoder': ['AdminServer', 'Concentrator'],
    'Endpoint': ['AdminServer', 'LogDecoder', 'LogCollector', 'LogHybrid'],
    'EndpointBroker': ['AdminServer', 'Concentrator'],
    'EndpointLogHybrid': ['AdminServer'],
    'ESAPrimary': ['AdminServer', 'Concentrator'],
    'ESASecondary': ['AdminServer', 'Concentrator'],
    'Gateway': ['AdminServer'],
    'LogCollector': ['AdminServer', 'LogDecoder'],
    'LogDecoder': ['AdminServer', 'LogCollector', 'Archiver', 'Concentrator'],
    'LogHybrid': ['AdminServer', 'LogCollector', 'Archiver', 'Broker', 'ESAPrimary'],
    'Malware': ['AdminServer'],
    'LogHybridRetention': ['AdminServer'],
    'PacketHybrid': ['AdminServer', 'Broker', 'ESAPrimary'],
    'Search': ['AdminServer'],
    'UEBA': ['AdminServer', 'LogDecoder', 'Endpoint'],
    'Warehouse': ['AdminServer']
}

def do_constants():
    'Displays constant values.'
    print(json.dumps(Services, sort_keys=True, indent=4))
    print(json.dumps(Components, sort_keys=True, indent=4))
    print(json.dumps(Appliance_Sockets, sort_keys=True, indent=4))
    #print(json.dumps(Direction, sort_keys=True, indent=4))
