"""
Filter
====================================
Collection of list and dict filtering utilities
"""

import re

class NoMatchException(Exception):
    pass

def by_service(hosts, service_name):
    """Filters host

    Parameters
    ----------
    hosts : [Host]
        List of host(s) in environment to filter
    
    service_name: str
        Name of service to filter by (supports regex)

    Yields
    -------
    Host
        next host running service

    """
    mask = re.compile(service_name)
    for host in hosts:
        for service in host.services:
            if mask.match(service):
                yield host