import click
import os
import logging
import json
import os.path
import hashlib
import nwtoolkit.color
from nwtoolkit.transform import minion_id_to_hostname

def sync_directory(directory, targets=None, env=None, root=None, autosync=False, autodeny=False, showgood=True):
    files = [f for f in os.scandir(directory) if f.is_file()]
    subdirectories = [d for d in os.scandir(directory) if d.is_dir()]
    for f in files:
        outOfSync = []
        try:
            remoteLocation = f.path.replace(root, '').replace('\\', '/')
        except IndexError:
            logging.error(f'Invalid file path {f.path}')
        with open(f, 'rb') as f_obj:
            f_hash = hashlib.sha1(f_obj.read()).hexdigest()
            logging.debug(f'{f.path} {remoteLocation} {f_hash}')
            logging.info(f'Checking {remoteLocation}')
            _, stdout, _ = env.head._exec(f'salt -L "{targets}" file.check_hash {remoteLocation} {f_hash} --out=json --out-indent=-1')
            for line in stdout:
                res = json.loads(line)
                key = list(res.keys())[0]
                hostname = minion_id_to_hostname(env.hosts, key)
                if isinstance(res[key], str):
                    res[key] = False
                if res[key] and showgood:
                    logging.info(f'{hostname}: {res[key]}')
                elif not res[key]:
                    outOfSync.append(key)
                    logging.info(f'{hostname}: {res[key]}')
            if len(outOfSync):
                if autodeny:
                    ans = False
                elif not autosync:
                    ans = click.confirm('Some systems are out of sync, trigger a sync now?')
                else:
                    ans = autosync
                if ans:
                    logging.info(f'Syncing file {f_hash}')
                    logging.debug(f'Target systems: {outOfSync}')
                    env.head.send_file(f_obj)
                    _, stdout, _ = env.head._exec(f"salt-cp -L '{', '.join(outOfSync)}' /tmp/{os.path.basename(f_obj.name)} {remoteLocation} --out=json --out-indent=-1")
                    for line in stdout:
                        logging.debug(line)
                    logging.info(f'Systems synced.')
    for subdirectory in subdirectories:
        sync_directory(subdirectory, targets=targets, env=env, root=root, autosync=autosync, autodeny=autodeny, showgood=showgood)

@click.command(help='Sync config files on multiple appliances')
@click.option('--source', help='Source of truth for config check', type=click.Path(exists=True, file_okay=False))
@click.option('--accept/--dont-accept', help='Accept all config changes automatically', default=False)
@click.option('--reject/--dont-reject', help='Reject all config changes automatically', default=False)
@click.option('--hide-synced/--show-synced', help='Show results for systems which are properly synced', default=False)
@click.pass_obj
def config_sync(env, source, accept, reject, hide_synced):
    directories = [d for d in os.scandir(source) if d.is_dir() and d.name.lower() != 'common']
    common = [d for d in os.scandir(source) if d.is_dir and d.name.lower() == 'common']
    logging.debug(directories)
    logging.debug(common)
    for directory in common:
        logging.info('Checking common settings')
        t = ', '.join([host.minion_id for host in env.hosts])
        sync_directory(directory, targets=t, env=env, root=directory.path, autosync=accept, autodeny=reject, showgood=hide_synced)
    for directory in directories:
        logging.info(f'Checking {directory.name} settings')
        t = ', '.join([host.minion_id for host in env.hosts if directory.name in host.services])
        if t == '':
            logging.error(f'No appliances are running a service named {directory.name}.')
            continue
        sync_directory(directory, targets=t, env=env, root=directory.path, autosync=accept, autodeny=reject, showgood=hide_synced)
