import click
import pathlib
import logging
from nwtoolkit.color import green, red, blue
from nwtoolkit.reporting import Report

logger = logging.getLogger(__name__)

def stdout(env, color):
    colorizer = {
            "red": lambda x: red(x),
            "green": lambda x: green(x),
            "blue": lambda x: blue(x),
            None: lambda x: x
    }
    for host in env.hosts:
        colorized_hostname = colorizer.get(color)(host.hostname)
        colorized_ipv4 = colorizer.get(color)(host.ipv4)

        logger.info(colorized_hostname)
        logger.debug(colorized_ipv4)

def report(env, output_format):
    template_path = f'{pathlib.Path(__file__).parent.absolute()}\\'
    report = Report(template_path, 'hello_world_template.htm')
    if output_format == 'report_file':
        report.to_file('hello_world.htm', hosts=env.hosts, overwrite=True)
    else:
        report.to_stdout()

@click.command(help='Example plugin, also serves as a connection test.')
@click.option('-r', '--red', 'color', flag_value='red', help='Print red text')
@click.option('-g', '--green', 'color', flag_value='green', help='Print green text')
@click.option('-b', '--blue', 'color', flag_value='blue', help='Print blue text')
@click.option('--report-file', 'output_format', flag_value='report_file', help='Outputs results to a file using a report')
@click.option('--report-stdout', 'output_format', flag_value='report_stdout', help='Outputs results to stdout using a report')
@click.option('--stdout', 'output_format', flag_value='stdout', help='Outputs results to stdout using Python logging', default=True)
@click.argument('output_path', type=click.File('a'), required=False)
@click.pass_obj
def demo(env, color, output_format, output_path):
    {
        'report_file': lambda: report(env, output_format),
        'report_stdout': lambda: report(env, output_format),
        'stdout': lambda: stdout(env, color)
    }.get(output_format)()
