import json
import os
import sys
import nwtoolkit.color as color
from nwtoolkit.constants.ports import Components, Services, Appliance_Sockets, Direction
import click
import pathlib
from nwtoolkit.reporting import Report
import nwtoolkit.transform as magical
import pandas as pd
import ipaddress
import pandas as pd
import networkx as nx
import matplotlib.pyplot as plt
import matplotlib.image as mpimg
from matplotlib import colors as mcolors
import glob
from numpy import sqrt
import glob
import random

#colors = dict(mcolors.BASE_COLORS, **mcolors.CSS4_COLORS)

def getType(env,targ_serv): #filters hosts by appliance type. Ex. returns minionids of all Brokers.
    dst_ids = []
    for host in env.hosts:
        service = host.services[0]
        if targ_serv == service.lower():
            #print(f"{targ_serv} --- {service}") #DEBUG <-- uncomment to debug services not testing
            dst_ids.append(host.minion_id)
            #print(dst_ids) #DEBUG <-- uncomment to debug services not testing
        elif targ_serv.lower() in host.services:
            dst_ids.append(host.minion_id)
        else:
            #print(f'{targ_serv} != {host.services} *NOT FOUND!*')
            continue
    return dst_ids


def get_layers(env):
    head_id = env.head.minion_id
    layers= {
        'node0':head_id
    }
    ordered_service_list = ['broker','concentrator','logdecoder','loghybrid','packethybrid','decoder']
    for node_type in ordered_service_list:
        minion_ids = getType(env,node_type)
        if minion_ids:
            #print(minion_ids)
            layers[node_type] = minion_ids
        else:
            continue   
    return layers

def get_node_data(env,layers,debug):
    node_data = {}
    for node_type, minion_ids in layers.items():
        #print(f"{node_type} | {minion_ids}") #DEBUG ONLY
        if node_type == 'node0':
            head_hostname = env.head.hostname
            #print(f"{head_hostname} --- {minion_ids}")
            salt_cmd = (f"salt '{minion_ids}' cmd.run 'ls /var/netwitness/broker/index' ")
            appliance_ipv4 = env.head.ipv4
            node_data[appliance_ipv4] = ''
            
        else:
            if "hybrid" in node_type:
                for mid in minion_ids:
                    #print(f"{node_type} --- {mid}")
                    salt_cmd = (f"salt '{mid}' cmd.run 'ls  /var/netwitness/concentrator/index' ")
                    appliance_ipv4 = magical.minion_id_to_ipaddr(env.hosts, mid)
                    node_data[appliance_ipv4] = ''
            else:
                for mid in minion_ids:
                    #print(f"{node_type} --- {mid}")
                    salt_cmd = (f"salt '{mid}' cmd.run 'ls /var/netwitness/{node_type}/index' ")
                    appliance_ipv4 = magical.minion_id_to_ipaddr(env.hosts, mid)
                    node_data[appliance_ipv4] = ''
        
        stdin, stdout, stderr = env.head.exec(salt_cmd)
        ip_list_temp = []
        for line in stdout:
            if ("50005" in line or "50003" in line) and "nwvalid" in line:
                parsed = line.split(" ")
                for item in parsed:
                    ip = item.split(".nwvalid\n")
                    for addr in ip:
                        ipv4 = addr.split(".500")
                        use_this_address = ipv4[0]
                        try:
                            ipv4 = ipaddress.ip_address(use_this_address)
                            print(use_this_address)
                            ip_list_temp.append(use_this_address)
                        except ValueError:
                            if debug is True:
                                print(f"Invalid IP Passed: {ipv4}. Ignoring..")
                            else:
                                continue    
                            continue
        node_data[appliance_ipv4] = ip_list_temp
    
    #print(f"{node_data.items()}")
    return node_data

def hierarchy_pos(G, root=None, width=1., vert_gap = 0.2, vert_loc = 0, xcenter = 0.5):
    
    '''
    width: horizontal space allocated for this branch - avoids overlap with other branches

    vert_gap: gap between levels of hierarchy

    vert_loc: vertical location of root

    xcenter: horizontal location of root
    '''
    if not nx.is_tree(G):
        raise TypeError('cannot use hierarchy_pos on a graph that is not a tree')

    if root is None:
        if isinstance(G, nx.DiGraph):
            root = next(iter(nx.topological_sort(G)))  #allows back compatibility with nx version 1.11
        else:
            root = random.choice(list(G.nodes))

    def _hierarchy_pos(G, root, width=1., vert_gap = 0.2, vert_loc = 0, xcenter = 0.5, pos = None, parent = None):
        '''
        see hierarchy_pos docstring for most arguments

        pos: a dict saying where all nodes go if they have been assigned
        parent: parent of this branch. - only affects it if non-directed

        '''

        if pos is None:
            pos = {root:(xcenter,vert_loc)}
        else:
            pos[root] = (xcenter, vert_loc)
        children = list(G.neighbors(root))
        if not isinstance(G, nx.DiGraph) and parent is not None:
            children.remove(parent)  
        if len(children)!=0:
            dx = width/len(children) 
            nextx = xcenter - width/2 - dx/2
            for child in children:
                nextx += dx
                pos = _hierarchy_pos(G,child, width = dx, vert_gap = vert_gap, 
                                    vert_loc = vert_loc-vert_gap, xcenter=nextx,
                                    pos=pos, parent = root)
        return pos
    return _hierarchy_pos(G, root, width, vert_gap, vert_loc, xcenter)

def build_chart(env, node_data):
    node_to = []
    node_from = []
    G = nx.Graph()
    img=mpimg.imread('nwtoolkit/plugins/mapper/rsa-logs.png')
    for source_node, node_connections in node_data.items():
        #num=0
        for destination_node in node_connections:
            if destination_node:    
                node_to.append(source_node)
                node_from.append(destination_node)
            else:
                continue
    #df = pd.DataFrame({'from':node_to,'to':node_from})
    #print(df)
    G.add_nodes_from(node_data.keys())
    merged_list = [(node_to[i], node_from[i]) for i in range(0, len(node_to))] 
    print(merged_list)
    G.add_edges_from(merged_list,imgage=img,size=0.1)
    val_map = {}
    color_map = []
    cmap = plt.get_cmap('Greens')
    #print(val_map.items())
    for node in G:
        serv = magical.ipv4_to_service(env.hosts,node)
        service = serv.lower()
        if service == 'adminserver':
            color_map.append('#7C2529') 
        elif service == 'broker':
            color_map.append('#425563')
        elif service == 'concentrator':
            color_map.append('#B7BF10')
        elif 'decoder' in service:
            color_map.append('#B7BF10')
          
    values = [val_map.get(node, '#425563') for node in G.nodes()]
    pos = hierarchy_pos(G,node_to[0])
    nx.draw(G, pos=pos, font_size=16,alpha=1, with_labels=False)
    print(f"1 | {pos}")
    pos_labels = pos
    ax=plt.gca()
    fig=plt.gcf()
    trans = ax.transData.transform
    trans2 = fig.transFigure.inverted().transform
    imsize = 0.1 # this is the image size
    for n in G.nodes():
        (x,y) = pos[n]
        xx,yy = trans((x,y)) # figure coordinates
        xa,ya = trans2((xx,yy)) # axes coordinates
        a = plt.axes([xa-imsize/2.0,ya-imsize/2.0, imsize, imsize ])
        a.imshow(img)
        a.set_aspect('equal')
        a.axis('off')

    #nx.draw_networkx_labels(G, pos = pos, font_size = 14, with_labels = True)
    for node_name, coordinates in pos_labels.items():
        print(f"{node_name} | {coordinates}")
        print(f"x - {coordinates[0]}")
        xc = coordinates[0]
        yc = coordinates[1]
        xc += 0.07
        new_coords = (xc,yc)
        pos_labels[node_name] = new_coords
            
    nx.draw_networkx_labels(G, pos_labels)
    plt.show()
    #plt.savefig('rough_sketch.png')
                    
@click.command(help='Mapper')
@click.option('--debug', 'debug', flag_value='True', help='Enables debug output', default=False)
@click.pass_obj
def mapper(env, debug):
    layers = get_layers(env)
    #print(layers.items()) DEBUG
    node_data = get_node_data(env,layers,debug)
    #print(node_data.items())
    build_chart(env,node_data)
