'''
Author: Cody Spooner
Date: 4/8/2020
Purpose: Open ALL service ports listed in the ports constant file. Listening ports are to be used with portcheck command from target appliance.
'''

import sys, os
import click
import json
import socket
import nwtoolkit
from nwtoolkit.constants.ports import Services
from nwtoolkit.color import green, red, blue
import time

serv = Services

def collect_ports(): #reads in service ports from ports constant file and removes duplicate values
    s_ports_dict ={}
    used_ports = []
    s_json = json.dumps(serv)
    s_dict = json.loads(s_json)
    for serv_name, port_list in s_dict.items():
        #print(b)
        for s_ports in port_list:
            s_ports_dict[serv_name]=s_ports
    for serv_name, serv_port in s_ports_dict.items():
        l_port = serv_port
        used_ports.append(l_port)
    listener_ports = [i for n, i in enumerate(used_ports) if i not in used_ports[:n]] #removes duplicates from list so sockets does have a binding error
    #print(listener_ports)
    return listener_ports

def make_socket(port_num): #binds the sockets with unique socket name per instance
    server_socket = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
    server_socket.setsockopt(socket.SOL_SOCKET, socket.SO_REUSEADDR, 1)
    server_socket.bind(('0.0.0.0', port_num))
    server_socket.listen(900)
    print(green("Binding: "+str(port_num)))
    return server_socket

def open_socket(): #opens sockets and creates socket list
    print(blue('''
    #######################################
    | This program will temporarily open  |
    | all NetWitness services ports.      |
    #######################################
    '''))
    wait = input("Press ENTER to continue.")
    collect_ports()
    socket_list=[]
    num = 0
    use_listener_ports = collect_ports()
    for port_num in use_listener_ports:
        num+=1
        try:
            socket_list.append(make_socket(port_num))
            #print("I works")
        except KeyboardInterrupt:
            print("CTRL-C RECEIVED. Stopping...")
            sys.exit(0)
        except Exception:
            #sys.stderr.write("[ERROR] %s\n" % msg[1])
            pass
    print(str(num)+" total ports listening.")
    for s in socket_list: #sets all sockets in socket_list to listen
        try:
            s.accept()
        except KeyboardInterrupt:
            print("CTRL-C RECEIVED. Stopping...")
            s.close()
            sys.exit(0)
@click.command(help='Test customer firewall(s) - Use with portcheck or curl.') 
@click.pass_obj
def listener(env): #main function
    open_socket()
