import jinja2
import pathlib
import nwtoolkit
import json
import logging
import platform

class Report():
    def __init__(self, template_file_path, template_filename):
        if ("windows" in platform.system().lower()):
            self.base_file_loader = jinja2.FileSystemLoader(f'{pathlib.Path(__file__).parent.absolute()}\\report_templates\\')
            self.header_image = f'{pathlib.Path(__file__).parent.absolute()}\\report_templates\\nwtoolkit_header.jpg'
            self.template_file_loader = jinja2.FileSystemLoader(template_file_path)
            self.choice_loader = jinja2.ChoiceLoader([self.base_file_loader, self.template_file_loader])
            self.jinja_environment = jinja2.Environment(loader=self.choice_loader)
            self.template = self.jinja_environment.get_template(template_filename)
        else:
            self.base_file_loader = jinja2.FileSystemLoader(f'{pathlib.Path(__file__).parent.absolute()}/report_templates/')
            self.header_image = f'{pathlib.Path(__file__).parent.absolute()}/report_templates/nwtoolkit_header.jpg'
            self.template_file_loader = jinja2.FileSystemLoader(template_file_path)
            self.choice_loader = jinja2.ChoiceLoader([self.base_file_loader, self.template_file_loader])
            self.jinja_environment = jinja2.Environment(loader=self.choice_loader)
            self.template = self.jinja_environment.get_template(template_filename)
    
    def to_file(self, output_file_path, overwrite=False, **kwargs):
        rendered_template = self.template.render(kwargs, header_image=self.header_image)
        if overwrite:
            with open(output_file_path, 'w', encoding='utf-8') as f:
                f.write(rendered_template)
        else:
            with open(output_file_path, 'x', encoding='utf-8') as f:
                f.write(rendered_template)

    def to_stdout(self, **kwargs):
        rendered_template = self.template.render(kwargs, header_image=self.header_image)
        logging.info(rendered_template)