"""
Transform
====================================
Collection of value transformation utilities
"""

class NoMatchError(Exception):
    """Exception raised when no match is found with a transform

    Attributes
    ----------
    msg : str
        Error message
    """

    def __init__(self):
        self.msg = 'No match found in dataset'
        super().__init__(self.msg)

def minion_id_to_hostname(hosts, minion_id):
    """Returns hostname of minion with matching ID

    Parameters
    ----------
    hosts : [Host]
        List of hosts to search
    
    minion_id: str
        minion_id to locate

    Returns
    -------
    str
        Hostname of minion with matching ID

    """
    for host in hosts:
        if host.minion_id == minion_id:
            return host.hostname
    else:
        raise NoMatchError
    
def ipaddr_to_hostname(hosts, ipv4):
    """Returns hostname of minion with matching ID

    Parameters
    ----------
    hosts : [Host]
        List of hosts to search
    
    minion_id: str
        minion_id to locate

    Returns
    -------
    str
        Hostname of minion with matching ID

    """
    for host in hosts:
        if host.ipv4 == ipv4:
            return host.hostname
    else:
        raise NoMatchError
    
def hostname_to_ipaddr(hosts, hostname):
    """Returns hostname of minion with matching ID

    Parameters
    ----------
    hosts : [Host]
        List of hosts to search
    
    minion_id: str
        minion_id to locate

    Returns
    -------
    str
        Hostname of minion with matching ID

    """
    for host in hosts:
        if host.hostname == hostname:
            return host.ipv4
    else:
        raise NoMatchError
    
def minion_id_to_ipaddr(hosts, minion_id):
    """Returns hostname of minion with matching ID

    Parameters
    ----------
    hosts : [Host]
        List of hosts to search
    
    minion_id: str
        minion_id to locate

    Returns
    -------
    str
        Hostname of minion with matching ID

    """
    for host in hosts:
        if host.minion_id == minion_id:
            return host.ipv4
    else:
        raise NoMatchError
    
def ipv4_to_service(hosts, ipv4):
    """Returns hostname of minion with matching ID

    Parameters
    ----------
    hosts : [Host]
        List of hosts to search

    minion_id: str
        minion_id to locate

    Returns
    -------
    str
        Hostname of minion with matching ID

    """
    for host in hosts:
        if host.ipv4 == ipv4:
            return host.services[0]
    else:
        raise NoMatchError